import { Node } from 'ts-morph';
interface CompilerHooks {
    onload?: (compiler: Compiler) => Promise<any>;
    onInserted?: (data: any) => Promise<any>;
    onRemoved?: (data: any) => Promise<any>;
    onPrettier?: (data: string) => Promise<any>;
    onError?: (e: Error) => Promise<any>;
}
interface CompilerOptions {
    sourceCode: string;
    fileNameOrPath: string;
    hooks: CompilerHooks;
}
export declare enum CreateProperty {
    'State' = "State",
    'Function' = "Function"
}
export type CreatePropertyType = 'string' | 'number' | 'object' | 'boolean' | 'function' | 'array';
export interface CreatePropertyItem {
    type: CreatePropertyType;
    name: string;
    comment?: string;
    value?: any;
    params?: string[];
}
export interface CreatePropertyConfig {
    override?: boolean;
}
interface ParseFunctionResult {
    name: string;
    params: string[];
    body: string;
}
declare class Compiler {
    private readonly options;
    private readonly fileNameOrPath;
    private project;
    constructor(options: CompilerOptions);
    /**
     * 初始化
     * @private
     */
    private init;
    private getSourceFile;
    /**
     * 获取默认值
     * @param variableType
     */
    getDefaultValue(variableType: CreatePropertyType): "''" | "0" | "false" | "{}" | "" | "[]" | "null";
    /**
     * 读取当前的code
     */
    get code(): string;
    getPrettierCode(): Promise<string>;
    /**
     * 删除属性及相关注释
     * @param stateObjectLiteral
     * @param property
     * @private
     */
    private removePropertyWithComments;
    /**
     * 创建属性
     * @type<CreateProperty> 类型
     * @param type
     * @param item
     * @param config
     */
    createProperty(type: CreateProperty | string, item: CreatePropertyItem, config?: CreatePropertyConfig): Promise<{
        type: CreateProperty | string;
        item: CreatePropertyItem;
        code: string;
    }>;
    /**
     * 移除掉属性
     * @param type
     * @param name
     */
    deleteProperty(type: CreateProperty | string, name: string): Promise<boolean>;
    /**
     * 提取节点的 JSDoc 注释
     * @param node ts-morph 节点
     * @returns 注释字符串或 undefined
     */
    getJsDocComment(node: Node): string | undefined | any;
    private getValueType;
    /**
     * 获取属性
     * @param type
     * @param name
     */
    getProperty(type: CreateProperty | string, name: string): Promise<CreatePropertyItem>;
    /**
     * 格式化代码
     * @param sourceCode
     */
    prettierCode(sourceCode: string): Promise<string>;
    /**
     * 解析函数的名称、参数集合和函数体
     * @param code 需要解析的代码字符串
     * @param functionName 需要提取的函数名称
     * @returns 包含函数名称、参数集合和函数体的对象
     */
    parseFunction(code: string, functionName: string): Promise<ParseFunctionResult>;
    /**
     * 编译器销毁
     */
    dispose(): void;
}
export { Compiler };
